package com.menagerie.ophelia

import androidx.compose.animation.ExperimentalSharedTransitionApi
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.material.Button
import androidx.compose.material.Text
import androidx.compose.material3.Scaffold
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.datastore.core.DataStore
import androidx.datastore.preferences.core.Preferences
import androidx.navigation.NavGraphBuilder
import androidx.navigation.NavHostController
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import com.menagerie.ophelia.HomeScreen.HomeScreen
import com.menagerie.ophelia.HomeScreen.MainMenu
import com.menagerie.ophelia.HomeScreen.Settings
import com.menagerie.ophelia.model.Recipe
import com.menagerie.ophelia.model.recipesList
import com.menagerie.ophelia.recipesdetails.RecipeDetails
import com.menagerie.ophelia.recipeslist.RecipesListScreen
import com.menagerie.ophelia.sensor.SensorManager

enum class DetailListAppScreen {
    List,
    Details,
}

@OptIn(ExperimentalSharedTransitionApi::class)
@Composable
fun App(
    sensorManager: SensorManager?,
    isLarge: Boolean = false,
    prefs: DataStore<Preferences>,
) {

    val navController = rememberNavController()
    OpheliaNavHost(
        navController = navController,
        isLarge = isLarge,
        sensorManager = sensorManager,
        prefs = prefs
    )


}

@Composable
fun OpheliaNavHost(
    navController: NavHostController,
    isLarge: Boolean,
    sensorManager: SensorManager?,
    prefs: DataStore<Preferences>
){
    val items by remember { mutableStateOf(recipesList) }
    var show by remember { mutableStateOf(false) }

    Scaffold {
        Column {
            //TODO : replace this with a composable task bar
            if (show) {
                Row {
                    Button(
                        onClick = {
                            navController.popBackStack()
                        }
                    ) {
                        Text(text = "Back - TEMP")
                    }
                    Button(
                        onClick = {
                            navController.navigate("mainMenu")
                        }
                    ) {
                        Text(text = "Home - TEMP")
                    }
                    Button(
                        onClick = {
                            navController.navigate("settings")
                        }
                    ) {
                        Text(text = "Settings - TEMP")
                    }
                    Button(onClick = {
                        //TODO : This should take the user to their bio page
                    }){
                        Text(text = "You - TEMP")
                    }
                }
            }

            NavHost(
                navController = navController,
                startDestination = "home"
            ) {
                polyculeGraph(navController)
                recipeGraph(
                    navController = navController,
                    items = items,
                    isLarge = isLarge,
                    sensorManager = sensorManager
                )
                welcomeGraph(navController)

                composable("home") {
                    HomeScreen {
                        show = true
                        navController.navigate("mainMenu")
                    }
                }
                composable("mainMenu") {
                    MainMenu(
                        onPolyClick = {
                            //TODO : This should take the user to their polycule's main page
                        },
                        onUserBioClick = {
                            //TODO : This should take the user to their bio page
                        },
                        onCookBookClick = {
                            navController.navigate(DetailListAppScreen.List.name)
                        },
                    )
                }

                composable("settings") {
                    Settings(prefs)
                }
            }

        }
    }
}

fun NavGraphBuilder.welcomeGraph(navController: NavHostController) {
//    composable("newUserStart") {
//        NewUserStartScreen { navController.navigate("newUserName") }
//    }
//    composable("newUserName") {
//        AddNameScreen { navController.navigate("newUserPronouns") }
//    }
//    composable("newUserPronouns") {
//        AddPronounsScreen { navController.navigate("newUserTags") }
//    }
//    composable("newUserTags") {
//        AddTagsScreen { navController.navigate("confirmBio") }
//    }
//    composable("confirmBio") {
//        ConfirmBio {
//            navController.popBackStack()
//            navController.navigate("polyculeHome")
//        }
//    }
//    composable("makePolycule") {
//        AddPolyculeScreen()
//    }
}

fun NavGraphBuilder.polyculeGraph(navController: NavHostController) {
//    composable("polyculeHome") {
//        PolyculeHomeView(
//            onBioClick = {
//                navController.navigate("bioDetail/${it.id}")
//            },
//            onAddClick = {
//                navController.navigate("addBio") {}
//            }
//        )
//    }
//    composable(
//        "bioDetail/{bioId}",
//        arguments = listOf(navArgument("bioId") {
//            type = NavType.LongType
//        })
//    ) {
//        BioDetailsScreen(
//            id = it.arguments?.getLong("bioId") ?: 0,
//            onBackClick = { navController.navigateUp() },
//            onEditClick = { id -> navController.navigate("editBio/${id}")}
//        )
//    }
//    composable("addBio") {
//        AddBiography()
//    }
//    composable(
//        "editBio/{bioId}",
//        arguments = listOf(navArgument("bioId") {
//            type = NavType.LongType
//        })
//    ){
//        EditBiography(bioId = it.arguments?.getLong("bioId") ?: 0) { navController.navigateUp() }
//    }
}

fun NavGraphBuilder.recipeGraph(
    navController: NavHostController,
    items: List<Recipe>,
    isLarge: Boolean,
    sensorManager: SensorManager?,
) {

    var currentRecipe = items.first()

    composable(route = DetailListAppScreen.List.name) {
        RecipesListScreen(
            isLarge = isLarge,
            items = items,
            onClick = { recipe ->
                currentRecipe = recipe
                navController.navigate(DetailListAppScreen.Details.name)
            })
    }
    composable(route = DetailListAppScreen.Details.name) {
        RecipeDetails(
            isLarge = isLarge,
            sensorManager = sensorManager,
            recipe = currentRecipe,
            goBack = { navController.popBackStack() }
        )
    }
}