package com.menagerie.ophelia.HomeScreen

import androidx.compose.foundation.layout.Column
import androidx.compose.material.Button
import androidx.compose.material.Text
import androidx.compose.material3.Scaffold
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.runtime.rememberCoroutineScope
import androidx.datastore.core.DataStore
import androidx.datastore.preferences.core.Preferences
import androidx.datastore.preferences.core.edit
import androidx.datastore.preferences.core.stringPreferencesKey
import kotlinx.coroutines.flow.map
import kotlinx.coroutines.launch

val themeKey = stringPreferencesKey("theme")
enum class Theme {
    Auto,
    Light,
    Dark
}

@Composable
fun Settings(prefs: DataStore<Preferences>) {

    val currentThemeString by prefs
        .data
        .map {
            it[themeKey] ?: Theme.Dark.name
        }
        .collectAsState(Theme.Dark.name)

    var currentTheme = Theme.valueOf(currentThemeString)
    val onThemeToggle = {
        currentTheme = when (currentTheme) {
            Theme.Auto -> Theme.Light
            Theme.Light -> Theme.Dark
            Theme.Dark -> Theme.Auto
        }
    }

    val scope = rememberCoroutineScope()

    Scaffold {
        Column {
            Button(onClick = {
                scope.launch {
                    onThemeToggle.invoke()
                    prefs.edit {
                        it[themeKey] = currentTheme.name
                    }
                }
            }) {
                Text(currentThemeString)
            }
        }
    }
}