package com.menagerie.ophelia

import androidx.compose.foundation.isSystemInDarkTheme
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.ui.window.Window
import androidx.compose.ui.window.application
import androidx.datastore.preferences.core.stringPreferencesKey
import com.menagerie.ophelia.ui.theme.OpheliaTheme
import kotlinx.coroutines.flow.map
import org.jetbrains.compose.resources.ExperimentalResourceApi

enum class Theme {
    Auto,
    Light,
    Dark
}

val themeKey = stringPreferencesKey("theme")

@OptIn(ExperimentalResourceApi::class)
fun main() {

    val prefs = createDataStore{
        "settings/files/$DATA_STORE_FILE_NAME"
    }
    application {
        Window(
            onCloseRequest = ::exitApplication,
            title = "Ophelia",
        ) {

            val currentThemeString by prefs
                .data
                .map {
                    it[themeKey] ?: Theme.Dark.name
                }
                .collectAsState(Theme.Dark.name)

            val currentTheme = Theme.valueOf(currentThemeString)
            val isDarkTheme: Boolean? = when (currentTheme) {
                Theme.Dark -> true
                Theme.Light -> false
                Theme.Auto -> null
            }
            OpheliaTheme(isDarkTheme ?: isSystemInDarkTheme()) {
                App(
                    sensorManager = null,
                    isLarge = true,
                    prefs = prefs
                )
            }
        }
    }
}